@@ -46,13 +46,13 @@ def main():
             if produto_skyhub:
                 print(produto_skyhub)
                 if produto_skyhub.price != row[1] or produto_skyhub.qty != row[2]:
-                    # produto_controller.atualiza_produto(produto_estoque)
+                    produto_controller.atualiza_produto(produto_estoque)
                     pass
 
             if produto_bling:
                 print(produto_bling)
                 if produto_bling.price != row[1] or produto_bling.qty != row[2]:
-                    # bling_controller.atualiza_produto(produto_estoque)
+                    bling_controller.atualiza_produto(produto_estoque)
                     pass
 
 
